<?php 
/**
 * Copyright oceanwebguru.com 2022
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author    Radadiya Ajay <aradadiya163@rest.com>
 * @copyright oceanwebguru.com 2022
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */
if (!defined('_PS_VERSION_')) {
    exit;
}
class OcCheckPincodeForPrestashop extends Module
{
    public function __construct()
    {
        $this->module_key = '8bd4256d6df4274631a6c381b814f96f';
        $this->name = 'occheckpincodeforprestashop';
        $this->tab = 'front_office_features';
        $this->version = '1.0.1';
        $this->author = 'Ajay Radadiya';
        $this->need_instance = 0;
        $this->ps_versions_compliancy = [
            'min' => '1.6',
            'max' => _PS_VERSION_,
        ];
        $this->bootstrap = true;
        parent::__construct();
        $this->displayName = $this->l('OC Check Pincode For Prestashop');
        $this->description = $this->l('This module use for check pincode for prestashop');
        $this->confirmUninstall = $this->l('Are you sure you want to uninstall?');
        if (!Configuration::get('MYMODULE_NAME')) {
            $this->warning = $this->l('No name provided');
        }
    }

    public function install()
    {
        $sql = 'CREATE TABLE IF NOT EXISTS `' . _DB_PREFIX_ . 'ocpincodetable` (
            `ocpincodeid` int UNSIGNED NOT NULL AUTO_INCREMENT,
            `ocpincode` varchar(255) NOT NULL,
            `ocstatename` varchar(255) NOT NULL,
            `occityname` varchar(255) NOT NULL,
            `ocdeliverywithindays` varchar(255) NOT NULL,
            `occodavailable` varchar(255) NOT NULL,
            PRIMARY KEY (`ocpincodeid`)
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8;';

        if (!Db::getInstance()->execute($sql)) {
            return false;
        }

        if (!parent::install() or
            !$this->registerHook('displayProductAdditionalInfo') or
            !$this->registerHook('displayBeforeBodyClosingTag') or
            !$this->registerHook('displayBackOfficeHeader') or
            !$this->registerHook('displayCartTotalPriceLabel') or
            !$this->registerHook('actionCartSave') or
            !$this->createTab() or
            !$this->registerHook('header')) {
            return false;
        }

        return true;
    }

    public function hookDisplayHeader()
    {
        $this->context->controller->addCSS($this->_path . '/views/css/occheckpincodefront.css', 'all');
        $OCCPFP_CARTBTN_SHOWPICO_WISE = Configuration::get('OCCPFP_CARTBTN_SHOWPICO_WISE');
        $OCCPFP_HIDEPOBTN_NOTAVAILIST = Configuration::get('OCCPFP_HIDEPOBTN_NOTAVAILIST');
        $OCCPFP_POPUP_ENADISA = Configuration::get('OCCPFP_POPUP_ENADISA');
        $OCCP_PLACEORDER_IFPINCODE_WROGTXT = Configuration::get('OCCP_PLACEORDER_IFPINCODE_WROGTXT');
        $OCPINCODE_POPUPAVAI_TXT = Configuration::get('OCPINCODE_POPUPAVAI_TXT');
        $OCPINCODE_POPUPNOTAVAI_TXT = Configuration::get('OCPINCODE_POPUPNOTAVAI_TXT');
        $ocloaderloadgif = __PS_BASE_URI__ . 'modules/occheckpincodeforprestashop/views/img/loading-load.gif';
        $myData = [
            'ocpincodeajaxcontrollerlink' => $this->context->link->getModuleLink('occheckpincodeforprestashop', 'occheckpincodefront', ['ajax' => true,'action' => 'OcpincodeControllerAction']), 
            'ocpicpopupajaxcontrollerlinks' => $this->context->link->getModuleLink('occheckpincodeforprestashop', 'occheckpincodepopup', ['ajax' => true,'action' => 'OcpincodepopupControllerAction']), 
            'OCCPFP_CARTBTN_SHOWPICO_WISE' => $OCCPFP_CARTBTN_SHOWPICO_WISE, 
            'OCCPFP_HIDEPOBTN_NOTAVAILIST' => $OCCPFP_HIDEPOBTN_NOTAVAILIST, 
            'OCCPFP_POPUP_ENADISA' => $OCCPFP_POPUP_ENADISA, 
            'OCCP_PLACEORDER_IFPINCODE_WROGTXT' => $OCCP_PLACEORDER_IFPINCODE_WROGTXT, 
            'OCPINCODE_POPUPAVAI_TXT' => $OCPINCODE_POPUPAVAI_TXT, 
            'OCPINCODE_POPUPNOTAVAI_TXT' => $OCPINCODE_POPUPNOTAVAI_TXT, 
            'ocloaderloadgif' => $ocloaderloadgif,
        ];
        $jsonData = json_encode($myData);
        $this->context->controller->registerJavascript(
            $this->name,
            $this->_path . 'views/js/occheckpincodefront.js',
            [
                'position' => 'bottom',
                'priority' => 150,
                'server' => 'remote',
                'attributes' => 'async',
            ],
        );
        Media::addJsDef(['occpipmyData' => $myData]);
    }

    public function createTab()
    {
        $tab = new Tab();
        $tab->name = [];
        foreach (Language::getLanguages() as $lang) {
            $tab->name[$lang['id_lang']] = $this->l('Oc Setting Pincode');
        }
        $tab->class_name = 'AdminocPincode';
        $tab->module = $this->name;
        $tab->icon = 'analytics';
        $tab->id_parent = (int) Tab::getIdFromClassName('SELL');
        $tab->add();
        $parentClassName = 'AdminocPincode';
        $parentTabId = (int) Tab::getIdFromClassName($parentClassName);
        if (!$parentTabId) {
            return false;
        }
        $miantab = new Tab();
        $miantab->active = 1;
        $miantab->class_name = 'AdminocPincode';
        $miantab->name = [];
        foreach (Language::getLanguages() as $lang) {
            $miantab->name[$lang['id_lang']] = 'Add Pincode';
        }
        $miantab->id_parent = $parentTabId;
        $miantab->module = $this->name;
        $miantab->add();
        $subtab = new Tab();
        $subtab->active = 1;
        $subtab->class_name = 'AdminSubPiincodeTab';
        $subtab->name = [];
        foreach (Language::getLanguages() as $lang) {
            $subtab->name[$lang['id_lang']] = 'List Pincode';
        }
        $subtab->id_parent = $parentTabId;
        $subtab->module = $this->name;
        $subtab->add();

        return true;
    }

    public function hookDisplayProductAdditionalInfo($params)
    {
        $params = $this->getParams();
        $this->context->smarty->assign($params);
        if (isset($_COOKIE['ocset_pincode'])) {
            $sql = 'SELECT * FROM `' . _DB_PREFIX_ . 'ocpincodetable` WHERE `ocpincode` = ' . (int) $_COOKIE['ocset_pincode'];
            $curntpincodeava = Db::getInstance()->executeS($sql);
            $checkpincoderecord = count($curntpincodeava);
            if (isset($_COOKIE['ocsavecurrentpincode'])) {
                $this->context->smarty->assign('ocsavecurrentpincode', $_COOKIE['ocsavecurrentpincode']);
            }
            $this->context->smarty->assign([
                'ocset_pincode' => $_COOKIE['ocset_pincode'], 
                'checkpincoderecord' => $checkpincoderecord,
            ]);
            if ($checkpincoderecord == 1) {
                $ocsstring = '+' . $curntpincodeava[0]['ocdeliverywithindays'] . ' days';
                $ochceckpincodedate = Date('jS M', strtotime($ocsstring));
                $dayofweek = date('D', strtotime($ocsstring));
                $deliverydate = $dayofweek . ', ' . $ochceckpincodedate;
                $extraFee = 10.00;
                $ocdelidateimg = $this->_path . 'views/img/schedule.png';
                if ($curntpincodeava[0]['occodavailable']) {
                    $occodavaitxt = Configuration::get('OCCP_CODAVAI_TXT');
                    $occashavailornt = $this->_path . 'views/img/money.png';
                } else {
                    $occodavaitxt = Configuration::get('OCCP_CODNOTAVAI_TXT');
                    $occashavailornt = $this->_path . 'views/img/money-not.png';
                }
                $this->context->smarty->assign([
                    'ocset_pincode' => $_COOKIE['ocset_pincode'], 
                    'curntpincodeava' => $curntpincodeava[0], 
                    'deliverydate' => Configuration::get('OCCP_DELIVERY_DATETXT') . ' ' . $deliverydate, 
                    'occodavaitxt' => $occodavaitxt, 
                    'ocdelidateimg' => $ocdelidateimg, 
                    'occashavailornt' => $occashavailornt,
                ]);
            }
        }

        return $this->display(__FILE__, '/views/templates/front/occheckpincode_front.tpl');
    }

    public function hookActionCartSave($params)
    {
        $occontroller = Tools::getValue('controller');
        if ($occontroller === 'product') {
            if (Configuration::get('OCCPFP_CARTBTN_SHOWPICO_WISE') == 'yes') {
                if (isset($_COOKIE['ocset_pincode'])) {
                    if ($_COOKIE['ocset_pincode'] == 'false') {
                      exit();
                    }
                }
            }
        }
    }

    public function hookDisplayCartTotalPriceLabel($params)
    {
        return $this->display(__FILE__, 'views/templates/hook/displayShoppingCart.tpl');
    }

    public function hookDisplayBeforeBodyClosingTag($params)
    {
        $params = $this->getParams();
        $this->context->smarty->assign($params);
        $oclocationimg = $this->_path . 'views/img/location.png';
        $OCCPFP_POPUP_ENADISA = Configuration::get('OCCPFP_POPUP_ENADISA');
        $OCCHECK_POPUP_BGCLR = Configuration::get('OCCHECK_POPUP_BGCLR');
        $OCCHECK_POPUP_TXTCLR = Configuration::get('OCCHECK_POPUP_TXTCLR');
        $OCCHECK_POPUP_SUBBTN_BGCLR = Configuration::get('OCCHECK_POPUP_SUBBTN_BGCLR');
        $OCCHECK_POPUP_SUBBTN_TXTCLR = Configuration::get('OCCHECK_POPUP_SUBBTN_TXTCLR');
        $this->context->smarty->assign([
            'oclocationimg' => $oclocationimg, 
            'OCCPFP_POPUP_ENADISA' => $OCCPFP_POPUP_ENADISA, 
            'OCCHECK_POPUP_BGCLR' => $OCCHECK_POPUP_BGCLR, 
            'OCCHECK_POPUP_TXTCLR' => $OCCHECK_POPUP_TXTCLR, 
            'OCCHECK_POPUP_SUBBTN_BGCLR' => $OCCHECK_POPUP_SUBBTN_BGCLR, 
            'OCCHECK_POPUP_SUBBTN_TXTCLR' => $OCCHECK_POPUP_SUBBTN_TXTCLR,
        ]);

        return $this->display(__FILE__, '/views/templates/front/occheckpincodepopup.tpl');
    }

    public function hookDisplayBackOfficeHeader()
    {
        if (Tools::getValue('configure') == 'occheckpincodeforprestashop') {
            $this->context->controller->addCSS($this->_path . '/views/css/coloris.min.css', 'all');
            $this->context->controller->addJS($this->_path . '/views/js/coloris.min.js', 'all');
            $this->context->controller->addCSS($this->_path . '/views/css/ocpincodeadmin.css', 'all');
            $this->context->controller->addJS($this->_path . '/views/js/ocadminpincode.js', 'all');
        }
    }

    public function getParams()
    {
        $params = [
            'OCCPFP_SHOWDATE_PICOBOX',
            'OCCPFP_SHOWCOD_PICOBOX',
            'OCCPFP_CARTBTN_SHOWPICO_WISE',
            'OCCPFP_HIDEPOBTN_NOTAVAILIST',
            'OCCPFP_POPUP_ENADISA',
            'OCCHECKPINBOXCLR',
            'OCCHECK_AVAITXTCLR',
            'OCCHECK_AND_CHANGE_BTNTXTCLR',
            'OCCHECK_AND_CHANGE_BTNBGCLR',
            'OCCHECK_DELIVERYDATE_TXTCLR',
            'OCCHECK_COD_TEXTCLR',
            'OCCHECK_POPUP_BGCLR',
            'OCCHECK_POPUP_TXTCLR',
            'OCCHECK_POPUP_SUBBTN_BGCLR',
            'OCCHECK_POPUP_SUBBTN_TXTCLR',
            'OCPINCODE_INPLACEHOLDERTXT',
            'OCCCHECK_PINCODBTN_TXT',
            'OCCCHECK_CHANGEBTN_TEXT',
            'OCCHECK_AVAIAT_TEXT',
            'OCPINCODE_NOT_AVAITXT',
            'OCCP_DELIVERY_DATETXT',
            'OCCP_CODAVAI_TXT',
            'OCCP_CODNOTAVAI_TXT',
            'OCCP_PLACEORDER_IFPINCODE_WROGTXT',
            'OCCP_AVAI_ATVALID_CITYSTATE_MSG',
            'OCPINCODE_LOCATAVAI_INFOTXT',
            'OCPINCODE_POPUP_SUBBTNTXT',
            'OCPINCODE_POPUP_INPPLACEHOL_TXT',
            'OCPINCODE_POPUPAVAI_TXT',
            'OCPINCODE_POPUPNOTAVAI_TXT',
            'OCPINCODE_EMPTY_FIELDTXT',
        ];
        $params = Configuration::getMultiple($params);
        extract($params);
        $params['OCCPFP_SHOWDATE_PICOBOX'] = ((empty($OCCPFP_SHOWDATE_PICOBOX)) ? 'yes' : $OCCPFP_SHOWDATE_PICOBOX);
        $params['OCCPFP_SHOWCOD_PICOBOX'] = ((empty($OCCPFP_SHOWCOD_PICOBOX)) ? 'yes' : $OCCPFP_SHOWCOD_PICOBOX);
        $params['OCCPFP_CARTBTN_SHOWPICO_WISE'] = ((empty($OCCPFP_CARTBTN_SHOWPICO_WISE)) ? 'yes' : $OCCPFP_CARTBTN_SHOWPICO_WISE);
        $params['OCCPFP_HIDEPOBTN_NOTAVAILIST'] = ((empty($OCCPFP_HIDEPOBTN_NOTAVAILIST)) ? 'yes' : $OCCPFP_HIDEPOBTN_NOTAVAILIST);
        $params['OCCPFP_POPUP_ENADISA'] = ((empty($OCCPFP_POPUP_ENADISA)) ? 'yes' : $OCCPFP_POPUP_ENADISA);
        $params['OCCHECKPINBOXCLR'] = ((empty($OCCHECKPINBOXCLR)) ? '#f6f6f6' : $OCCHECKPINBOXCLR);
        $params['OCCHECK_AVAITXTCLR'] = ((empty($OCCHECK_AVAITXTCLR)) ? '#000000' : $OCCHECK_AVAITXTCLR);
        $params['OCCHECK_AND_CHANGE_BTNTXTCLR'] = ((empty($OCCHECK_AND_CHANGE_BTNTXTCLR)) ? '#ffffff' : $OCCHECK_AND_CHANGE_BTNTXTCLR);
        $params['OCCHECK_AND_CHANGE_BTNBGCLR'] = ((empty($OCCHECK_AND_CHANGE_BTNBGCLR)) ? '#24b9d7' : $OCCHECK_AND_CHANGE_BTNBGCLR);
        $params['OCCHECK_DELIVERYDATE_TXTCLR'] = ((empty($OCCHECK_DELIVERYDATE_TXTCLR)) ? '#7a7a7a' : $OCCHECK_DELIVERYDATE_TXTCLR);
        $params['OCCHECK_COD_TEXTCLR'] = ((empty($OCCHECK_COD_TEXTCLR)) ? '#7a7a7a' : $OCCHECK_COD_TEXTCLR);
        $params['OCCHECK_POPUP_BGCLR'] = ((empty($OCCHECK_POPUP_BGCLR)) ? '#ffffff' : $OCCHECK_POPUP_BGCLR);
        $params['OCCHECK_POPUP_TXTCLR'] = ((empty($OCCHECK_POPUP_TXTCLR)) ? '#000000' : $OCCHECK_POPUP_TXTCLR);
        $params['OCCHECK_POPUP_SUBBTN_BGCLR'] = ((empty($OCCHECK_POPUP_SUBBTN_BGCLR)) ? '#24b9d7' : $OCCHECK_POPUP_SUBBTN_BGCLR);
        $params['OCCHECK_POPUP_SUBBTN_TXTCLR'] = ((empty($OCCHECK_POPUP_SUBBTN_TXTCLR)) ? '#ffffff' : $OCCHECK_POPUP_SUBBTN_TXTCLR);
        $params['OCPINCODE_INPLACEHOLDERTXT'] = ((empty($OCPINCODE_INPLACEHOLDERTXT)) ? 'Enter Pincode' : $OCPINCODE_INPLACEHOLDERTXT);
        $params['OCCCHECK_PINCODBTN_TXT'] = ((empty($OCCCHECK_PINCODBTN_TXT)) ? 'CHECK' : $OCCCHECK_PINCODBTN_TXT);
        $params['OCCCHECK_CHANGEBTN_TEXT'] = ((empty($OCCCHECK_CHANGEBTN_TEXT)) ? 'CHANGE' : $OCCCHECK_CHANGEBTN_TEXT);
        $params['OCCHECK_AVAIAT_TEXT'] = ((empty($OCCHECK_AVAIAT_TEXT)) ? 'Check Availability At' : $OCCHECK_AVAIAT_TEXT);
        $params['OCPINCODE_NOT_AVAITXT'] = ((empty($OCPINCODE_NOT_AVAITXT)) ? 'We Are Not Services This Place' : $OCPINCODE_NOT_AVAITXT);
        $params['OCCP_DELIVERY_DATETXT'] = ((empty($OCCP_DELIVERY_DATETXT)) ? 'Delivery Date ' : $OCCP_DELIVERY_DATETXT);
        $params['OCCP_CODAVAI_TXT'] = ((empty($OCCP_CODAVAI_TXT)) ? 'Case On Delivery Available' : $OCCP_CODAVAI_TXT);
        $params['OCCP_CODNOTAVAI_TXT'] = ((empty($OCCP_CODNOTAVAI_TXT)) ? 'Case On Delivery Not Available' : $OCCP_CODNOTAVAI_TXT);
        $params['OCCP_PLACEORDER_IFPINCODE_WROGTXT'] = ((empty($OCCP_PLACEORDER_IFPINCODE_WROGTXT)) ? 'Choose valid zipcode in product page then place order' : $OCCP_PLACEORDER_IFPINCODE_WROGTXT);
        $params['OCCP_AVAI_ATVALID_CITYSTATE_MSG'] = ((empty($OCCP_AVAI_ATVALID_CITYSTATE_MSG)) ? 'YES, We Deliver to' : $OCCP_AVAI_ATVALID_CITYSTATE_MSG);
        $params['OCPINCODE_LOCATAVAI_INFOTXT'] = ((empty($OCPINCODE_LOCATAVAI_INFOTXT)) ? 'Check your location availability info' : $OCPINCODE_LOCATAVAI_INFOTXT);
        $params['OCPINCODE_POPUP_SUBBTNTXT'] = ((empty($OCPINCODE_POPUP_SUBBTNTXT)) ? 'CHECK' : $OCPINCODE_POPUP_SUBBTNTXT);
        $params['OCPINCODE_POPUP_INPPLACEHOL_TXT'] = ((empty($OCPINCODE_POPUP_INPPLACEHOL_TXT)) ? 'Enter Pincode' : $OCPINCODE_POPUP_INPPLACEHOL_TXT);
        $params['OCPINCODE_POPUPAVAI_TXT'] = ((empty($OCPINCODE_POPUPAVAI_TXT)) ? 'We are available currently servicing your area.' : $OCPINCODE_POPUPAVAI_TXT);
        $params['OCPINCODE_POPUPNOTAVAI_TXT'] = ((empty($OCPINCODE_POPUPNOTAVAI_TXT)) ? 'We Are Not Services This Place' : $OCPINCODE_POPUPNOTAVAI_TXT);
        $params['OCPINCODE_EMPTY_FIELDTXT'] = ((empty($OCPINCODE_EMPTY_FIELDTXT)) ? 'Pincode field should not be empty!' : $OCPINCODE_EMPTY_FIELDTXT);

        return $params;
    }

    public function getContent()
    {
        $output = '';
        if (Tools::isSubmit('ProInqsendTokenMessage')) {
            Configuration::updateValue('OCCPFP_SHOWDATE_PICOBOX', Tools::getValue('OCCPFP_SHOWDATE_PICOBOX'));
            Configuration::updateValue('OCCPFP_SHOWCOD_PICOBOX', Tools::getValue('OCCPFP_SHOWCOD_PICOBOX'));
            Configuration::updateValue('OCCPFP_CARTBTN_SHOWPICO_WISE', Tools::getValue('OCCPFP_CARTBTN_SHOWPICO_WISE'));
            Configuration::updateValue('OCCPFP_HIDEPOBTN_NOTAVAILIST', Tools::getValue('OCCPFP_HIDEPOBTN_NOTAVAILIST'));
            Configuration::updateValue('OCCPFP_POPUP_ENADISA', Tools::getValue('OCCPFP_POPUP_ENADISA'));
            Configuration::updateValue('OCCHECKPINBOXCLR', Tools::getValue('OCCHECKPINBOXCLR'));
            Configuration::updateValue('OCCHECK_AVAITXTCLR', Tools::getValue('OCCHECK_AVAITXTCLR'));
            Configuration::updateValue('OCCHECK_AND_CHANGE_BTNTXTCLR', Tools::getValue('OCCHECK_AND_CHANGE_BTNTXTCLR'));
            Configuration::updateValue('OCCHECK_DELIVERYDATE_TXTCLR', Tools::getValue('OCCHECK_DELIVERYDATE_TXTCLR'));
            Configuration::updateValue('OCCHECK_COD_TEXTCLR', Tools::getValue('OCCHECK_COD_TEXTCLR'));
            Configuration::updateValue('OCCHECK_POPUP_BGCLR', Tools::getValue('OCCHECK_POPUP_BGCLR'));
            Configuration::updateValue('OCCHECK_POPUP_TXTCLR', Tools::getValue('OCCHECK_POPUP_TXTCLR'));
            Configuration::updateValue('OCCHECK_POPUP_SUBBTN_BGCLR', Tools::getValue('OCCHECK_POPUP_SUBBTN_BGCLR'));
            Configuration::updateValue('OCCHECK_POPUP_SUBBTN_TXTCLR', Tools::getValue('OCCHECK_POPUP_SUBBTN_TXTCLR'));
            Configuration::updateValue('OCPINCODE_INPLACEHOLDERTXT', Tools::getValue('OCPINCODE_INPLACEHOLDERTXT'));
            Configuration::updateValue('OCCCHECK_PINCODBTN_TXT', Tools::getValue('OCCCHECK_PINCODBTN_TXT'));
            Configuration::updateValue('OCCCHECK_CHANGEBTN_TEXT', Tools::getValue('OCCCHECK_CHANGEBTN_TEXT'));
            Configuration::updateValue('OCCHECK_AVAIAT_TEXT', Tools::getValue('OCCHECK_AVAIAT_TEXT'));
            Configuration::updateValue('OCPINCODE_NOT_AVAITXT', Tools::getValue('OCPINCODE_NOT_AVAITXT'));
            Configuration::updateValue('OCCP_DELIVERY_DATETXT', Tools::getValue('OCCP_DELIVERY_DATETXT'));
            Configuration::updateValue('OCCP_CODAVAI_TXT', Tools::getValue('OCCP_CODAVAI_TXT'));
            Configuration::updateValue('OCCP_CODNOTAVAI_TXT', Tools::getValue('OCCP_CODNOTAVAI_TXT'));
            Configuration::updateValue('OCCP_PLACEORDER_IFPINCODE_WROGTXT', Tools::getValue('OCCP_PLACEORDER_IFPINCODE_WROGTXT'));
            Configuration::updateValue('OCCP_AVAI_ATVALID_CITYSTATE_MSG', Tools::getValue('OCCP_AVAI_ATVALID_CITYSTATE_MSG'));
            Configuration::updateValue('OCPINCODE_LOCATAVAI_INFOTXT', Tools::getValue('OCPINCODE_LOCATAVAI_INFOTXT'));
            Configuration::updateValue('OCPINCODE_POPUP_SUBBTNTXT', Tools::getValue('OCPINCODE_POPUP_SUBBTNTXT'));
            Configuration::updateValue('OCPINCODE_POPUP_INPPLACEHOL_TXT', Tools::getValue('OCPINCODE_POPUP_INPPLACEHOL_TXT'));
            Configuration::updateValue('OCPINCODE_POPUPAVAI_TXT', Tools::getValue('OCPINCODE_POPUPAVAI_TXT'));
            Configuration::updateValue('OCPINCODE_POPUPNOTAVAI_TXT', Tools::getValue('OCPINCODE_POPUPNOTAVAI_TXT'));
            Configuration::updateValue('OCPINCODE_EMPTY_FIELDTXT', Tools::getValue('OCPINCODE_EMPTY_FIELDTXT'));
            $output .= $this->displayConfirmation($this->trans(
                'Settings updated.',
                [],
                'Admin.Global',
            ));
        }
        if (isset($this->ps_version)) {
            $params = $this->getParams();
            $moduleAdminLink = Context::getContext()->link->getAdminLink('AdminModules', true, false, $params);
        } else {
            $comurl = '&configure=' . $this->name . '&module_name=' . $this->name;
            $moduleAdminLink = Context::getContext()->link->getAdminLink('AdminModules', true) . $comurl;
        }
        $currentPage = 'occheckpincodeforprestashop';
        $page = Tools::getValue('page');
        if (!empty($page)) {
            $currentPage = Tools::getValue('page');
        }
        $params = $this->getParams();
        $this->context->smarty->assign([
            'module_name' => $this->name, 
            'module_version' => $this->version, 
            'moduleAdminLink' => $moduleAdminLink, 
            'module_display' => $this->displayName, 
            'currentPage' => $currentPage, 
            'ps_base_dir' => Tools::getHttpHost(true), 
            'ps_version' => _PS_VERSION_, 
            'isPs17' => isset($this->ps_version), 
            'occpforpre_params' => $params,
        ]);
        $output .= '';

        return $output . $this->context->smarty->fetch($this->local_path . 'views/templates/admin/ocpincodeadminsettings.tpl');
    }
}
